#ifndef LIBRARY_SECURITY_CONF_H
#define LIBRARY_SECURITY_CONF_H

#define KYLIN_SECURITY_CONF "/etc/kysec/kysec.conf"

#define SECURITY_MODULE_KYSEC       "kysec"
#define SECURITY_MODULE_SELINUX     "selinux"
#define SECURITY_MODULE_APPARMOR     "apparmor"

#define SECURITY_KEY_KYSEC_STATUS       "kysec_status"
#define SECURITY_KEY_KYSEC_EXECTL       "kysec_exectl"
#define SECURITY_KEY_KYSEC_NETCTL       "kysec_netctl"
#define SECURITY_KEY_KYSEC_FPRO         "kysec_fpro"
#define SECURITY_KEY_KYSEC_KMODPRO      "kysec_kmodpro"
#define SECURITY_KEY_KYSEC_PPRO         "kysec_ppro"
#define SECURITY_KEY_KYSEC_3ADM         "kysec_3adm"
#define SECURITY_KEY_KYSEC_DEVCTL       "kysec_devctl"

#define SECURITY_KEY_SELINUX            "selinux"
#define SECURITY_KEY_ENFORCING          "enforcing"

#define SECURITY_KEY_APPARMOR            "apparmor"

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 配置文件中添加安全模块，同时在 security/lsm= 中添加该模块
 *
 * @param[in] module_name 要添加的安全模块名
 *
 * @return 成功返回0，失败返回-1
 */
int security_config_module_add(const char *module_name);

/**
 * @brief 移除配置文件中相应安全模块的配置信息，同时在 security/lsm= 中删除该模块
 *
 * @param[in] module_name 要移除的安全模块名
 *
 * @return 成功返回0，失败返回-1
 */
int security_config_module_remove(const char *module_name);

/**
 * @brief 设置相应安全模块的配置信息，必须先调用 security_config_module_add添加了该模块
 *
 * @param[in] module_name 要设置的安全模块名
 * @param[in] key         安全模块配置项
 * @param[in] value       配置项的值
 * @param[in] op          添加或删除，删除为0，否则为添加
 *
 * @return 成功返回0，失败返回-1
 */
int security_config_module_set(const char *module_name, const char *key, int value, int op);

/**
 * @brief 获取相应安全模块的配置状态
 *
 * @param[in] module_name 要设置的安全模块名
 * @param[in] key         安全模块配置项
 *
 * @return 失败返回-1, 其他为获取状态值
 */
int security_config_module_status_get(const char *module_name, const char *key);

#ifdef __cplusplus
}
#endif

#endif //LIBRARY_SECURITY_CONF_H
